Package: affy
Version: 1.90.0
Title: Methods for Affymetrix Oligonucleotide Arrays
Author: Rafael A. Irizarry <rafa@ds.dfci.harvard.edu>, Laurent Gautier
        <lgautier@gmail.com>, Benjamin Milo Bolstad
        <bmb@bmbolstad.com>, and Crispin Miller
        <cmiller@picr.man.ac.uk> with contributions from Magnus
        Astrand <Magnus.Astrand@astrazeneca.com>, Leslie M. Cope
        <cope@mts.jhu.edu>, Robert Gentleman, Jeff Gentry, Conrad
        Halling <challing@agilixcorp.com>, Wolfgang Huber, James
        MacDonald <jmacdon@u.washington.edu>, Benjamin I. P. Rubinstein,
        Christopher Workman <workman@cbs.dtu.dk>, John Zhang
Maintainer: Robert D. Shear <rshear@ds.dfci.harvard.edu>
URL: https://bioconductor.org/packages/affy
BugReports: https://github.com/rafalab/affy/issues
Depends: R (>= 2.8.0), BiocGenerics (>= 0.1.12), Biobase (>= 2.5.5)
Imports: affyio (>= 1.13.3), BiocManager, graphics, grDevices, methods,
        preprocessCore, stats, utils
Suggests: tkWidgets (>= 1.19.0), affydata, widgetTools, hgu95av2cdf
LinkingTo: preprocessCore
Description: The package contains functions for exploratory
        oligonucleotide array analysis. The dependence on tkWidgets
        only concerns few convenience functions. 'affy' is fully
        functional without it.
License: LGPL (>= 2.0)
Collate: ProgressBarText.R ppset.ttest.R ppsetApply.R expressoWidget.R
        getCDFenv.R AffyRNAdeg.R avdiff.R barplot.ProbeSet.R
        bg.Affy.chipwide.R bg.R expresso.R fit.li.wong.R
        generateExprVal.method.avgdiff.R
        generateExprVal.method.liwong.R generateExprVal.method.mas.R
        generateExprVal.method.medianpolish.R
        generateExprVal.method.playerout.R hlog.R justrma.R
        loess.normalize.R maffy.R mas5.R merge.AffyBatch.R
        normalize.constant.R normalize.contrasts.R
        normalize.invariantset.R normalize.loess.R normalize.qspline.R
        normalize.quantiles.R pairs.AffyBatch.R plot.density.R
        plotLocation.R plot.ProbeSet.R pmcorrect.mas.R AffyBatch.R
        mva.pairs.R ProbeSet.R read.affybatch.R rma.R summary.R
        tukey.biweight.R whatcdf.R xy2indices.R zzz.R
biocViews: Microarray, OneChannel, Preprocessing
LazyLoad: yes
git_url: https://git.bioconductor.org/packages/affy
git_branch: RELEASE_3_23
git_last_commit: 7ed56e7
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: yes
Packaged: 2026-04-28 20:32:35 UTC; biocbuild
